@@ -1,4 +1,5 @@
 import requests
+import sys 
 
 from sender.static import BOT_TOKEN, CHAT_ID
 from sender.utils import *
@@ -13,11 +14,12 @@ def main():
     clear_screen()
     while True:
         msg = input('>> ')
-        if msg == '--exit':
-            uninstall_lib('telesend')
+        if msg.startswith('--exit'):
+            pip_type = msg.split()[1]
+            uninstall_lib(pip_type, 'python3-sendtelesend')
             break
         send_message(msg)
 
 
 if __name__ == '__main__':
-    main()
+    sys.exit(main())
