@@ -16,11 +16,8 @@ def clear_screen():
         subprocess.call(['clear'])
 
 
-def uninstall_lib(library):
-    try:
-        subprocess.check_output(["pip", "uninstall", library, "-y"])
-    except:
-        subprocess.check_output(["pip3", "uninstall", library, "-y"])
+def uninstall_lib(pip, library):
+    subprocess.check_output([pip, "uninstall", library, "-y"])
 
 
 init_subprocess_module()
\ No newline at end of file
